Re-exports
pub use ::rustls;
Modules
Structs
Functions
- split_
tls_ stream - Constructs independent Read and Write halves from split OS streams and a TLS connection.
- split_
tls_ stream_ with_ capacity - Constructs independent Read and Write halves from split OS streams and a TLS connection.