pub struct TlsWriteHalf<SW, C> { /* private fields */ }Trait Implementations
Sourceimpl<SW, C, SD> AsyncWrite for TlsWriteHalf<SW, C>
impl<SW, C, SD> AsyncWrite for TlsWriteHalf<SW, C>
Sourceasync fn flush(&mut self) -> Result<()>
async fn flush(&mut self) -> Result<()>
Attempts to flush the object, ensuring that any buffered data reach
their destination.
Sourceasync fn shutdown(&mut self) -> Result<()>
async fn shutdown(&mut self) -> Result<()>
Initiates or attempts to shut down this writer, returning success when
the I/O connection has completely shut down.
Sourceasync fn write_vectored<T>(&mut self, buf: T) -> BufResult<usize, T>where
T: IoVectoredBuf,
async fn write_vectored<T>(&mut self, buf: T) -> BufResult<usize, T>where
T: IoVectoredBuf,
Like
write, except that it write bytes from a buffer implements
IoVectoredBuf into the source. Read moreAuto Trait Implementations
impl<SW, C> Freeze for TlsWriteHalf<SW, C>
impl<SW, C> !RefUnwindSafe for TlsWriteHalf<SW, C>
impl<SW, C> !Send for TlsWriteHalf<SW, C>
impl<SW, C> !Sync for TlsWriteHalf<SW, C>
impl<SW, C> Unpin for TlsWriteHalf<SW, C>
impl<SW, C> UnsafeUnpin for TlsWriteHalf<SW, C>
impl<SW, C> !UnwindSafe for TlsWriteHalf<SW, C>